# -*- coding: UTF-8 -*-
# Code generated by lark suite oapi sdk gen

from typing import List, Dict, Any
from ....utils.dt import to_json_decorator
import attr




@to_json_decorator
@attr.s
class Image(object):
    image_key = attr.ib(type=str, default=None, metadata={'json': 'image_key'})




