# -*- coding: UTF-8 -*-
# Code generated by lark suite oapi sdk gen

from typing import List, Dict, Any
from ....utils.dt import to_json_decorator
import attr




@to_json_decorator
@attr.s
class Identity(object):
    identity_name = attr.ib(type=str, default=None, metadata={'json': 'identity_name'})
    identity_code = attr.ib(type=str, default=None, metadata={'json': 'identity_code'})
    mobile = attr.ib(type=str, default=None, metadata={'json': 'mobile'})



@to_json_decorator
@attr.s
class IdentityCreateReqBody(object):
    identity_name = attr.ib(type=str, default=None, metadata={'json': 'identity_name'})
    identity_code = attr.ib(type=str, default=None, metadata={'json': 'identity_code'})
    mobile = attr.ib(type=str, default=None, metadata={'json': 'mobile'})


@attr.s
class IdentityCreateResult(object):
    verify_uid = attr.ib(type=str, default=None, metadata={'json': 'verify_uid'})