# -*- coding: UTF-8 -*-
# Code generated by lark suite oapi sdk gen

from typing import List, Dict, Any
from ....utils.dt import to_json_decorator
import attr


@to_json_decorator
@attr.s
class Bot(object):
    pass


@to_json_decorator
@attr.s
class BotInfo(object):
    activate_status = attr.ib(type=int, default=None, metadata={'json': 'activate_status'})
    app_name = attr.ib(type=str, default=None, metadata={'json': 'app_name'})
    avatar_url = attr.ib(type=str, default=None, metadata={'json': 'avatar_url'})
    ip_white_list = attr.ib(type=List[str], default=None, metadata={'json': 'ip_white_list'})
    open_id = attr.ib(type=str, default=None, metadata={'json': 'open_id'})


@attr.s
class BotGetResult(object):
    bot = attr.ib(type=BotInfo, default=None, metadata={'json': 'bot'})
